import { useContractRead, useContractAbi, useContractWriteAndWait } from '@0xflair/react-common';
import 'ethers';
import 'react-query';
import { useCallback } from 'react';

/******************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */

function __rest(s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
}

const useOzHasRole = (_a) => {
    var { enabled = true, role, address } = _a, restOfConfig = __rest(_a, ["enabled", "role", "address"]);
    return useContractRead(Object.assign({ contractFqn: 'openzeppelin/access/AccessControl', functionName: 'hasRole', args: role && address ? [role, address] : undefined, enabled: Boolean(enabled && role && address) }, restOfConfig));
};

const useOzOwner = (config) => {
    return useContractRead(Object.assign({ contractFqn: 'openzeppelin/access/Ownable', functionName: 'owner' }, config));
};

const useOzRoleGranter = (_a) => {
    var { contractVersion, contractAddress, signerOrProvider, role, address } = _a, restOfConfig = __rest(_a, ["contractVersion", "contractAddress", "signerOrProvider", "role", "address"]);
    const contractInterface = useContractAbi({
        contractVersion,
        contractFqn: 'openzeppelin/access/AccessControl',
    });
    return useContractWriteAndWait(Object.assign({ contractInterface, functionName: 'grantRole', args: [role, address], contractAddress,
        signerOrProvider }, restOfConfig));
};

const useOzRoleRenouncer = (_a) => {
    var { contractVersion, contractAddress, signerOrProvider, role, address } = _a, restOfConfig = __rest(_a, ["contractVersion", "contractAddress", "signerOrProvider", "role", "address"]);
    const contractInterface = useContractAbi({
        contractVersion,
        contractFqn: 'openzeppelin/access/AccessControl',
    });
    return useContractWriteAndWait(Object.assign({ contractInterface, functionName: 'renounceRole', args: [role, address], contractAddress,
        signerOrProvider }, restOfConfig));
};

const useOzRoleRevoker = (_a) => {
    var { contractVersion, contractAddress, signerOrProvider, role, address } = _a, restOfConfig = __rest(_a, ["contractVersion", "contractAddress", "signerOrProvider", "role", "address"]);
    const contractInterface = useContractAbi({
        contractVersion,
        contractFqn: 'openzeppelin/access/AccessControl',
    });
    return useContractWriteAndWait(Object.assign({ contractInterface, functionName: 'revokeRole', args: [role, address], contractAddress,
        signerOrProvider }, restOfConfig));
};

const useERC20BalanceOf = (_a) => {
    var { accountAddress } = _a, restOfConfig = __rest(_a, ["accountAddress"]);
    return useContractRead(Object.assign({ contractFqn: 'openzeppelin/token/ERC20/ERC20', functionName: 'balanceOf', args: accountAddress ? [accountAddress] : undefined }, restOfConfig));
};

const useERC20Decimals = (config) => {
    return useContractRead(Object.assign({ contractFqn: 'openzeppelin/token/ERC20/ERC20', functionName: 'decimals' }, config));
};

const useERC20Name = (config) => {
    return useContractRead(Object.assign({ contractFqn: 'openzeppelin/token/ERC20/ERC20', functionName: 'name' }, config));
};

const useERC20Symbol = (config) => {
    return useContractRead(Object.assign({ contractFqn: 'openzeppelin/token/ERC20/ERC20', functionName: 'symbol' }, config));
};

const useERC20TotalSupply = (config) => {
    return useContractRead(Object.assign({ contractFqn: 'openzeppelin/token/ERC20/ERC20', functionName: 'totalSupply' }, config));
};

const useERC20Transfer = (_a) => {
    var { contractVersion, contractAddress, signerOrProvider, role, to, amount } = _a, restOfConfig = __rest(_a, ["contractVersion", "contractAddress", "signerOrProvider", "role", "to", "amount"]);
    const contractInterface = useContractAbi({
        contractVersion,
        contractFqn: 'openzeppelin/token/ERC20/ERC20',
    });
    return useContractWriteAndWait(Object.assign({ contractInterface, functionName: 'transfer', args: [to, amount], contractAddress,
        signerOrProvider }, restOfConfig));
};

const useERC20RoleBasedMint = (_a) => {
    var { contractVersion, contractAddress, signerOrProvider, role, to, amount } = _a, restOfConfig = __rest(_a, ["contractVersion", "contractAddress", "signerOrProvider", "role", "to", "amount"]);
    const contractInterface = useContractAbi({
        contractVersion,
        contractFqn: 'openzeppelin/token/ERC20/presets/ERC20PresetMinterPauser',
    });
    return useContractWriteAndWait(Object.assign({ contractInterface, functionName: 'mint', args: [to, amount], contractAddress,
        signerOrProvider }, restOfConfig));
};

const useERC721Name = (config) => {
    return useContractRead(Object.assign({ contractFqn: 'openzeppelin/token/ERC721/extensions/IERC721Metadata', functionName: 'name' }, config));
};

const useERC721Symbol = (config) => {
    return useContractRead(Object.assign({ contractFqn: 'openzeppelin/token/ERC721/extensions/IERC721Metadata', functionName: 'symbol' }, config));
};

const useERC721TransferFrom = (_a) => {
    var { contractVersion, contractAddress, signerOrProvider, from, to, tokenId } = _a, restOfConfig = __rest(_a, ["contractVersion", "contractAddress", "signerOrProvider", "from", "to", "tokenId"]);
    const contractInterface = useContractAbi({
        contractVersion,
        contractFqn: 'openzeppelin/token/ERC721/ERC721',
    });
    return useContractWriteAndWait(Object.assign({ contractInterface, functionName: 'transferFrom', args: [from, to, tokenId], contractAddress,
        signerOrProvider }, restOfConfig));
};

const useERC721IsApprovedForAll = (_a) => {
    var { owner, operator, enabled } = _a, rest = __rest(_a, ["owner", "operator", "enabled"]);
    return useContractRead(Object.assign({ contractFqn: 'openzeppelin/token/ERC721/ERC721', functionName: 'isApprovedForAll', args: [owner, operator], enabled: Boolean(enabled && owner && operator) }, rest));
};

const useERC721SetApprovalForAll = (_a) => {
    var { contractVersion, contractAddress, signerOrProvider, operator, approved } = _a, restOfConfig = __rest(_a, ["contractVersion", "contractAddress", "signerOrProvider", "operator", "approved"]);
    const contractInterface = useContractAbi({
        contractVersion,
        contractFqn: 'openzeppelin/token/ERC721/ERC721',
    });
    return useContractWriteAndWait(Object.assign({ contractInterface, functionName: 'setApprovalForAll', args: [operator, approved], contractAddress,
        signerOrProvider }, restOfConfig));
};

const useERC721Approver = ({ contractAddress, contractVersion, chainId, enabled, watch, cacheOnBlock, signerOrProvider, owner, operator, writeOverrides, }) => {
    const { data: isApprovedForAll, error: isApprovedForAllError, isLoading: isApprovedForAllLoading, refetch: fetchIsApprovedForAll, } = useERC721IsApprovedForAll({
        chainId,
        contractAddress,
        contractVersion,
        owner,
        operator,
        enabled,
        watch,
        cacheOnBlock,
    });
    const { data: setApprovalForAllData, error: setApprovalForAllError, isLoading: setApprovalForAllLoading, writeAndWait, } = useERC721SetApprovalForAll({
        contractAddress,
        contractVersion,
        signerOrProvider,
        overrides: writeOverrides,
    });
    const setApprovalForAll = useCallback((approved = true) => {
        return writeAndWait([operator, approved]).then(() => {
            fetchIsApprovedForAll();
            setTimeout(() => {
                fetchIsApprovedForAll();
            }, 500);
        });
    }, [fetchIsApprovedForAll, operator, writeAndWait]);
    return {
        data: Object.assign({ isApprovedForAll }, setApprovalForAllData),
        error: setApprovalForAllError || isApprovedForAllError,
        isLoading: setApprovalForAllLoading || isApprovedForAllLoading,
        fetchIsApprovedForAll,
        setApprovalForAll,
    };
};

const useERC721TotalSupply = (config) => {
    return useContractRead(Object.assign({ contractFqn: 'collections/ERC721/extensions/ERC721AutoIdMinterExtension', functionName: 'totalSupply' }, config));
};

export { useERC20BalanceOf, useERC20Decimals, useERC20Name, useERC20RoleBasedMint, useERC20Symbol, useERC20TotalSupply, useERC20Transfer, useERC721Approver, useERC721IsApprovedForAll, useERC721Name, useERC721SetApprovalForAll, useERC721Symbol, useERC721TotalSupply, useERC721TransferFrom, useOzHasRole, useOzOwner, useOzRoleGranter, useOzRoleRenouncer, useOzRoleRevoker };
//# sourceMappingURL=index.es.js.map
